import 'package:flutter/material.dart';
import 'package:auto_route/auto_route.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';
import 'package:router/ext/auto_router_extensions.dart';
import 'package:shared/utils/log_utils.dart';
import 'package:widgets/my_load_image.dart';
import 'package:widgets/ext/ex_widget.dart';

import '../../../router/page/property_page_router.dart';
import '../vm/property_vm.dart';

@RoutePage()
class PropertyPage extends HookConsumerWidget {
  const PropertyPage({Key? key}) : super(key: key);

  //启动当前页面
  static void startInstance({BuildContext? context}) {
    if (context != null) {
      context.router.push(const PropertyPageRoute());
    } else {
      appRouter.push(const PropertyPageRoute());
    }
  }

  // 顶部tab 切换
  Widget _buildTopSection(BuildContext context, WidgetRef ref, _vm) {
    final topSectionsData = _vm.topSectionsData;
    return Container(
      color: Colors.white,
      child: Center(
        child: Row(
          mainAxisAlignment: MainAxisAlignment.center,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: List.generate(topSectionsData.length, (index) {
            final item = topSectionsData[index];
            return Flexible(
              flex: 1,
              child: Column(
                children: [
                  MyAssetImage(
                    item['icon'],
                    width: MediaQuery.of(context).size.width / topSectionsData.length - 36,
                    height: 70,
                  ).onTap(
                    () {
                      _vm.switchPage(index, context);
                    },
                    type: ClickType.throttle,
                  ),
                  SizedBox.fromSize(size: const Size(0, 9)),
                  Text(
                    item['title'],
                    maxLines: 1, // 设置最大行数为2
                    overflow: TextOverflow.ellipsis, // 超出部分用省略号表示
                    style: const TextStyle(fontSize: 13.0, color: Colors.black, fontWeight: FontWeight.w500), // 设置字体大小
                  ),
                ],
              ),
            ).marginOnly(left: 18, right: 18, top: 10, bottom: 10);
          }),
        ),
      ),
    );
  }

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final _vm = ref.read(propertyVmProvider.notifier);
    return DefaultTabController(
      length: 4,
      child: Scaffold(
          appBar: AppBar(
            title: const Text("Property"),
            bottomOpacity: 0.0, // 取消下横线
            titleTextStyle: const TextStyle(color: Colors.black),
          ),
          body: Row(
            children: [
              Expanded(
                child: Column(
                  children: [
                    _buildTopSection(context, ref, _vm),
                    const Expanded(
                      child: AutoRouter(),
                    )
                  ],
                ),
              )
            ],
          )),
    );
  }
}
