import 'package:flutter/material.dart';

//定义扩展方便获取到颜色值
extension ThemeDataExtension on ThemeData {
  AppColorsTheme get appColors => extension<AppColorsTheme>()!;
}

extension AppColorsThemeExtensions on BuildContext {
  AppColorsTheme get appColors => Theme.of(this).extension<AppColorsTheme>()!;
}

class AppColorsTheme extends ThemeExtension<AppColorsTheme> {
  //亮色主题的自定义颜色值
  static const _colorPrimary = Color(0xFF4161D0); //主题色
  static const _colorFCFCFC = Color(0xFFFCFCFC);
  static const _color6C6C6C = Color(0xFF6C6C6C);
  static const _color666666 = Color(0xFF666666);
  static const _colorD7DBE7 = Color(0xffD7DBE7);
  static const _colorBDBDBD = Color(0xFFBDBDBD);
  static const _colorF2F2F2 = Color(0xFFF2F2F2);

  //暗色主题的一些自定义颜色值
  static const _darkBlackBg = Color(0xFF0F0F0F);
  static const _darkBlackItem = Color(0xFF1D1D1E);
  static const _darkBlackItemLight = Color(0xFF3B3933);
  static const _darkBlackItemLightMost = Color(0xFF5C5850);
  static const _darkBlackItemDivider = Color(0xFF3B3B3F);

  // 页面中真正使用到的颜色名称
  final Color backgroundDefault; //页面背景颜色
  final Color btnBgDefault;  //按钮背景颜色
  final Color searchFiledBorder; //搜索框的边框颜色
  final Color authFiledHint; //输入框默认的提示文本颜色
  final Color authFiledText; //输入框默认的文本颜色
  final Color authFiledBG; //输入框默认的背景颜色
  final Color textPrimary; //主题色文本
  final Color textBlack; //黑色文本
  final Color textDarkGray; //深灰色 666 文本

  // 私有的构造函数
  const AppColorsTheme._internal({
    required this.backgroundDefault,
    required this.btnBgDefault,
    required this.searchFiledBorder,
    required this.authFiledHint,
    required this.authFiledText,
    required this.authFiledBG,
    required this.textPrimary,
    required this.textBlack,
    required this.textDarkGray,
  });

  // 浅色主题工厂方法
  factory AppColorsTheme.light() {
    return const AppColorsTheme._internal(
      backgroundDefault: _colorFCFCFC,
      btnBgDefault: _colorPrimary,
      searchFiledBorder: _colorD7DBE7,
      authFiledHint: _colorBDBDBD,
      authFiledText: Colors.black,
      authFiledBG: _colorF2F2F2,
      textPrimary: _colorPrimary,
      textBlack: Colors.black,
      textDarkGray: _color666666,
    );
  }

  // 暗色主题工厂方法
  factory AppColorsTheme.dark() {
    return const AppColorsTheme._internal(
      backgroundDefault: _darkBlackBg,
      btnBgDefault: _darkBlackItem,
      searchFiledBorder: _darkBlackItem,
      authFiledHint: _colorD7DBE7,
      authFiledText: Colors.white,
      authFiledBG: _darkBlackItem,
      textPrimary: Colors.white,
      textBlack: Colors.white,
      textDarkGray: Colors.white,
    );
  }

  @override
  ThemeExtension<AppColorsTheme> copyWith({bool? lightMode}) {
    if (lightMode == null || lightMode == true) {
      return AppColorsTheme.light();
    }
    return AppColorsTheme.dark();
  }

  @override
  AppColorsTheme lerp(covariant ThemeExtension<AppColorsTheme>? other, double t) {
    if (other is! AppColorsTheme) return this;
    return AppColorsTheme._internal(
      backgroundDefault: Color.lerp(backgroundDefault, other.backgroundDefault, t)!,
      btnBgDefault: Color.lerp(btnBgDefault, other.btnBgDefault, t)!,
      searchFiledBorder: Color.lerp(searchFiledBorder, other.searchFiledBorder, t)!,
      authFiledHint: Color.lerp(authFiledHint, other.authFiledHint, t)!,
      authFiledText: Color.lerp(authFiledText, other.authFiledText, t)!,
      authFiledBG: Color.lerp(authFiledBG, other.authFiledBG, t)!,
      textPrimary: Color.lerp(textPrimary, other.textPrimary, t)!,
      textBlack: Color.lerp(textBlack, other.textBlack, t)!,
      textDarkGray: Color.lerp(textDarkGray, other.textDarkGray, t)!,
    );
  }
}
